@@ -74,7 +74,7 @@ class Context(EventBComponent):
     def to_txt(self, out_path, merge=False):
         exists = os.path.exists(out_path)
 
-        with open(out_path, 'a') as f:
+        with open(out_path, 'a', encoding="utf8") as f:
             if merge and exists:
                 f.write('\n\n')
 
@@ -85,7 +85,7 @@ class Context(EventBComponent):
 
             f.write('end\n')
 
-        self._trim_trailing_whitespaces(out_path)
+        self._post_process_file(out_path)
 
     def __print_context_head(self, f):
         f.write('context ' + self.get_component_name())
